# pytest-requirements


pytest plugin providing markers to link tests to requirements and usecases.


Please see the [quickstart documentation](http://cta-computing.gitlab-pages.cta-observatory.org/common/pytest-requirements/latest/quickstart.html) to get started.
